==> secretsmanager-1.60.0-sources.jar: software/amazon/awscdk/services/secretsmanager/SecretAttachmentTargetProps.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * Attachment target specifications.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.438Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.SecretAttachmentTargetProps")
@software.amazon.jsii.Jsii.Proxy(SecretAttachmentTargetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SecretAttachmentTargetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The id of the target to attach the secret to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetId();

    /**
     * The type of the target to attach the secret to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.AttachmentTargetType getTargetType();

    /**
     * @return a {@link Builder} of {@link SecretAttachmentTargetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SecretAttachmentTargetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SecretAttachmentTargetProps> {
        private java.lang.String targetId;
        private software.amazon.awscdk.services.secretsmanager.AttachmentTargetType targetType;

        /**
         * Sets the value of {@link SecretAttachmentTargetProps#getTargetId}
         * @param targetId The id of the target to attach the secret to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetId(java.lang.String targetId) {
            this.targetId = targetId;
            return this;
        }

        /**
         * Sets the value of {@link SecretAttachmentTargetProps#getTargetType}
         * @param targetType The type of the target to attach the secret to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetType(software.amazon.awscdk.services.secretsmanager.AttachmentTargetType targetType) {
            this.targetType = targetType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SecretAttachmentTargetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SecretAttachmentTargetProps build() {
            return new Jsii$Proxy(targetId, targetType);
        }
    }

    /**
     * An implementation for {@link SecretAttachmentTargetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SecretAttachmentTargetProps {
        private final java.lang.String targetId;
        private final software.amazon.awscdk.services.secretsmanager.AttachmentTargetType targetType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.targetId = this.jsiiGet("targetId", java.lang.String.class);
            this.targetType = this.jsiiGet("targetType", software.amazon.awscdk.services.secretsmanager.AttachmentTargetType.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String targetId, final software.amazon.awscdk.services.secretsmanager.AttachmentTargetType targetType) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.targetId = java.util.Objects.requireNonNull(targetId, "targetId is required");
            this.targetType = java.util.Objects.requireNonNull(targetType, "targetType is required");
        }

        @Override
        public java.lang.String getTargetId() {
            return this.targetId;
        }

        @Override
        public software.amazon.awscdk.services.secretsmanager.AttachmentTargetType getTargetType() {
            return this.targetType;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("targetId", om.valueToTree(this.getTargetId()));
            data.set("targetType", om.valueToTree(this.getTargetType()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-secretsmanager.SecretAttachmentTargetProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SecretAttachmentTargetProps.Jsii$Proxy that = (SecretAttachmentTargetProps.Jsii$Proxy) o;

            if (!targetId.equals(that.targetId)) return false;
            return this.targetType.equals(that.targetType);
        }

        @Override
        public int hashCode() {
            int result = this.targetId.hashCode();
            result = 31 * result + (this.targetType.hashCode());
            return result;
        }
    }
}

==> secretsmanager-1.100.0-sources.jar: software/amazon/awscdk/services/secretsmanager/SecretAttachmentTargetProps.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * Attachment target specifications.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:15.667Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.SecretAttachmentTargetProps")
@software.amazon.jsii.Jsii.Proxy(SecretAttachmentTargetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SecretAttachmentTargetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The id of the target to attach the secret to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetId();

    /**
     * The type of the target to attach the secret to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.AttachmentTargetType getTargetType();

    /**
     * @return a {@link Builder} of {@link SecretAttachmentTargetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SecretAttachmentTargetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SecretAttachmentTargetProps> {
        private java.lang.String targetId;
        private software.amazon.awscdk.services.secretsmanager.AttachmentTargetType targetType;

        /**
         * Sets the value of {@link SecretAttachmentTargetProps#getTargetId}
         * @param targetId The id of the target to attach the secret to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetId(java.lang.String targetId) {
            this.targetId = targetId;
            return this;
        }

        /**
         * Sets the value of {@link SecretAttachmentTargetProps#getTargetType}
         * @param targetType The type of the target to attach the secret to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetType(software.amazon.awscdk.services.secretsmanager.AttachmentTargetType targetType) {
            this.targetType = targetType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SecretAttachmentTargetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SecretAttachmentTargetProps build() {
            return new Jsii$Proxy(targetId, targetType);
        }
    }

    /**
     * An implementation for {@link SecretAttachmentTargetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SecretAttachmentTargetProps {
        private final java.lang.String targetId;
        private final software.amazon.awscdk.services.secretsmanager.AttachmentTargetType targetType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.targetId = software.amazon.jsii.Kernel.get(this, "targetId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.targetType = software.amazon.jsii.Kernel.get(this, "targetType", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.AttachmentTargetType.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String targetId, final software.amazon.awscdk.services.secretsmanager.AttachmentTargetType targetType) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.targetId = java.util.Objects.requireNonNull(targetId, "targetId is required");
            this.targetType = java.util.Objects.requireNonNull(targetType, "targetType is required");
        }

        @Override
        public final java.lang.String getTargetId() {
            return this.targetId;
        }

        @Override
        public final software.amazon.awscdk.services.secretsmanager.AttachmentTargetType getTargetType() {
            return this.targetType;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("targetId", om.valueToTree(this.getTargetId()));
            data.set("targetType", om.valueToTree(this.getTargetType()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-secretsmanager.SecretAttachmentTargetProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SecretAttachmentTargetProps.Jsii$Proxy that = (SecretAttachmentTargetProps.Jsii$Proxy) o;

            if (!targetId.equals(that.targetId)) return false;
            return this.targetType.equals(that.targetType);
        }

        @Override
        public final int hashCode() {
            int result = this.targetId.hashCode();
            result = 31 * result + (this.targetType.hashCode());
            return result;
        }
    }
}
